@@ -6,15 +6,21 @@ from typing import Union
 
 import pandas as pd
 
-from zvt.api.kdata import get_kdata_schema, default_adjust_type
+from zvt.api.kdata import get_kdata_schema, default_adjust_type, get_latest_kdata_date, get_trade_dates
+from zvt.api.selector import get_entity_ids_by_filter
 from zvt.api.utils import get_recent_report_date
 from zvt.contract import Mixin, AdjustType
 from zvt.contract.api import decode_entity_id, get_entity_schema, get_entity_ids
 from zvt.contract.drawer import Drawer
 from zvt.domain import FundStock, StockValuation, BlockStock, Block
-from zvt.factors import TechnicalFactor
-from zvt.utils import now_pd_timestamp, next_date, pd_is_not_null
-from zvt.utils.time_utils import month_start_end_ranges, to_time_str, pre_month_end_date
+from zvt.utils.pd_utils import pd_is_not_null
+from zvt.utils.time_utils import (
+    month_start_end_ranges,
+    to_date_time_str,
+    is_same_date,
+    now_pd_timestamp,
+    date_time_by_interval,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -53,6 +59,110 @@ def get_top_performance_by_month(
         yield start_timestamp, end_timestamp, top
 
 
+def get_top_performance_entities_by_periods(
+    entity_provider,
+    data_provider,
+    target_date=None,
+    periods=None,
+    entity_ids=None,
+    ignore_new_stock=True,
+    ignore_st=True,
+    entity_type="stock",
+    adjust_type=None,
+    top_count=50,
+    turnover_threshold=100000000,
+    turnover_rate_threshold=0.02,
+    return_type=TopType.positive,
+):
+    if periods is None:
+        periods = [*range(1, 21)]
+    if not adjust_type:
+        adjust_type = default_adjust_type(entity_type=entity_type)
+    kdata_schema = get_kdata_schema(entity_type=entity_type, adjust_type=adjust_type)
+    entity_schema = get_entity_schema(entity_type=entity_type)
+
+    if not target_date:
+        target_date = get_latest_kdata_date(provider=data_provider, entity_type=entity_type, adjust_type=adjust_type)
+
+    if not entity_ids:
+        filter_entity_ids = get_entity_ids_by_filter(
+            provider=entity_provider,
+            ignore_st=ignore_st,
+            ignore_new_stock=ignore_new_stock,
+            entity_schema=entity_schema,
+            target_date=target_date,
+        )
+    else:
+        filter_entity_ids = entity_ids
+
+    if not filter_entity_ids:
+        return []
+
+    filter_turnover_df = kdata_schema.query_data(
+        filters=[
+            kdata_schema.turnover >= turnover_threshold,
+            kdata_schema.turnover_rate >= turnover_rate_threshold,
+        ],
+        provider=data_provider,
+        start_timestamp=date_time_by_interval(target_date, -7),
+        end_timestamp=target_date,
+        index="entity_id",
+        columns=["entity_id", "code"],
+    )
+    if filter_entity_ids:
+        filter_entity_ids = set(filter_entity_ids) & set(filter_turnover_df.index.tolist())
+    else:
+        filter_entity_ids = filter_turnover_df.index.tolist()
+
+    if not filter_entity_ids:
+        return []
+
+    logger.info(f"{entity_type} filter_entity_ids size: {len(filter_entity_ids)}")
+    filters = [kdata_schema.entity_id.in_(filter_entity_ids)]
+    selected = []
+    current_start = None
+    real_period = 1
+    for i, period in enumerate(periods):
+        real_period = max(real_period, period)
+        while True:
+            start = date_time_by_interval(target_date, -real_period)
+            trade_days = get_trade_dates(entity_type=entity_type, start=start, end=target_date)
+            if not trade_days:
+                logger.info(f"no trade days in: {start} to {target_date}")
+                real_period = real_period + 1
+                continue
+            if current_start and is_same_date(current_start, trade_days[0]):
+                logger.info("ignore same trade days")
+                real_period = real_period + 1
+                continue
+            break
+        current_start = trade_days[0]
+        current_end = trade_days[-1]
+
+        logger.info(f"trade days in: {current_start} to {current_end}, real_period: {real_period} ")
+        positive_df, negative_df = get_top_performance_entities(
+            entity_type=entity_type,
+            start_timestamp=current_start,
+            end_timestamp=current_end,
+            kdata_filters=filters,
+            pct=1,
+            show_name=True,
+            entity_provider=entity_provider,
+            data_provider=data_provider,
+            adjust_type=adjust_type,
+            return_type=return_type,
+        )
+
+        if return_type == TopType.positive:
+            df = positive_df
+        else:
+            df = negative_df
+        if pd_is_not_null(df):
+            selected = selected + df.index[:top_count].tolist()
+            selected = list(dict.fromkeys(selected))
+    return selected, real_period
+
+
 def get_top_performance_entities(
     entity_type="stock",
     start_timestamp=None,
@@ -75,7 +185,7 @@ def get_top_performance_entities(
         entity_filters = []
     if list_days:
         entity_schema = get_entity_schema(entity_type=entity_type)
-        list_date = next_date(start_timestamp, -list_days)
+        list_date = date_time_by_interval(start_timestamp, -list_days)
         entity_filters += [entity_schema.list_date <= list_date]
 
     filter_entities = get_entity_ids(
@@ -135,7 +245,7 @@ def get_top_fund_holding_stocks(timestamp=None, pct=0.3, by=None):
         columns = ["entity_id", "market_cap"]
 
     entity_ids = fund_cap_df.index.tolist()
-    start_timestamp = next_date(timestamp, -30)
+    start_timestamp = date_time_by_interval(timestamp, -30)
     cap_df = StockValuation.query_data(
         entity_ids=entity_ids,
         filters=[
@@ -208,7 +318,7 @@ def get_performance_stats_by_month(
             data_provider=data_provider,
         )
         if stats:
-            month_stats[f"{to_time_str(start_timestamp)}"] = stats
+            month_stats[f"{to_date_time_str(start_timestamp)}"] = stats
 
     return pd.DataFrame.from_dict(data=month_stats, orient="index")
 
@@ -471,20 +581,38 @@ def get_change_ratio(
 
 
 if __name__ == "__main__":
-    get_change_ratio(start_timestamp="2022-06-01")
+    normal_stock_ids = get_entity_ids_by_filter(
+        entity_type="stockus", provider="em", ignore_delist=True, ignore_st=False, ignore_new_stock=False
+    )
+
+    print(
+        get_top_performance_entities_by_periods(
+            entity_provider="em",
+            data_provider="em",
+            entity_ids=normal_stock_ids,
+            entity_type="stockus",
+            adjust_type=AdjustType.qfq,
+            turnover_threshold=10000000,
+            turnover_rate_threshold=0,
+        )
+    )
+
 
 # the __all__ is generated
 __all__ = [
     "WindowMethod",
     "TopType",
     "get_top_performance_by_month",
+    "get_top_performance_entities_by_periods",
     "get_top_performance_entities",
     "get_top_fund_holding_stocks",
     "get_performance",
     "get_performance_stats_by_month",
     "get_performance_stats",
     "get_top_volume_entities",
+    "get_top_turnover_rate_entities",
     "get_top_entities",
     "show_month_performance",
     "show_industry_composition",
+    "get_change_ratio",
 ]
