@@ -15,8 +15,7 @@ ZVT_TEST_DATA_PATH = os.path.join(ZVT_TEST_HOME, "data")
 DATA_SAMPLE_ZIP_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), "samples", "data.zip"))
 
 # ****** setting for stocks ****** #
-# 覆盖维度 银行/保险/企业/券商 创业板 中小板 主板
-SAMPLE_STOCK_CODES = ["000001", "000783", "000778", "603220", "601318", "000338", "002572", "300027"]
+SAMPLE_STOCK_CODES = ["000001", "000002"]
 
 # 沪深300，证券，中证500，上证50，创业板，军工,传媒,资源
 SAMPLE_ETF_CODES = ["510300", "512880", "510500", "510050", "159915", "512660", "512980", "510410"]
