@@ -21,7 +21,7 @@ class RecorderState(ZvtInfoBase, StateMixin):
     Schema for storing recorder state
     """
 
-    __tablename__ = "recoder_state"
+    __tablename__ = "recorder_state"
 
 
 class TaggerState(ZvtInfoBase, StateMixin):
@@ -42,5 +42,6 @@ class FactorState(ZvtInfoBase, StateMixin):
 
 register_schema(providers=["zvt"], db_name="zvt_info", schema_base=ZvtInfoBase)
 
+
 # the __all__ is generated
 __all__ = ["StateMixin", "RecorderState", "TaggerState", "FactorState"]
