@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.orm import declarative_base
 
 from zvt.contract.register import register_schema, register_entity
 from zvt.contract.schema import TradableEntity
@@ -14,5 +14,6 @@ class Future(FutureMetaBase, TradableEntity):
 
 register_schema(providers=["em"], db_name="future_meta", schema_base=FutureMetaBase)
 
+
 # the __all__ is generated
 __all__ = ["Future"]
